<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">

  <title>{{ site.title | default: site.github.repository_name }}</title>

  <style>
    body {
      font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Helvetica, Arial, sans-serif;
      line-height: 1.6;
      color: #333;
      max-width: 1200px;
      margin: 0 auto;
      padding: 20px;
    }
    .container {
      display: flex;
      gap: 30px;
    }
    .sidebar {
      flex: 0 0 250px;
      background: #f6f8fa;
      padding: 20px;
      border-radius: 6px;
      height: fit-content;
    }
    .content {
      flex: 1;
      min-width: 0;
    }
    h1, h2, h3 {
      color: #24292e;
      margin-top: 30px;
      margin-bottom: 15px;
    }
    h1 {
      font-size: 2.5em;
      border-bottom: 1px solid #e1e4e8;
      padding-bottom: 10px;
    }
    h2 {
      font-size: 2em;
      border-bottom: 1px solid #e1e4e8;
      padding-bottom: 8px;
    }
    h3 {
      font-size: 1.5em;
    }
    pre {
      background: #f6f8fa;
      padding: 16px;
      border-radius: 6px;
      overflow-x: auto;
      margin: 15px 0;
    }
    code {
      background: #f6f8fa;
      padding: 2px 4px;
      border-radius: 3px;
      font-family: SFMono-Regular, Consolas, "Liberation Mono", Menlo, monospace;
    }
    pre code {
      background: none;
      padding: 0;
    }
    .nav ul {
      list-style: none;
      padding: 0;
    }
    .nav li {
      margin: 10px 0;
    }
    .nav a {
      color: #0366d6;
      text-decoration: none;
    }
    .nav a:hover {
      text-decoration: underline;
    }
    @media (max-width: 768px) {
      .container {
        flex-direction: column;
      }
      .sidebar {
        flex: none;
      }
    }
  </style>
</head>
<body>
  <div class="container">
    <div class="sidebar">
      <h1>{{ site.title | default: site.github.repository_name }}</h1>
      <p>{{ site.description | default: site.github.project_tagline }}</p>
      
      {% if site.github.is_project_page %}
      <p class="view">
        <a href="{{ site.github.repository_url }}">
          View the Project on GitHub<br>
          <small>{{ site.github.repository_nwo }}</small>
        </a>
      </p>
      {% endif %}

      <nav class="nav">
        <h3>Navigation</h3>
        <ul>
          <li><a href="{{ '/' | relative_url }}">Home</a></li>
          <li><a href="{{ '/installation' | relative_url }}">Installation</a></li>
          <li><a href="{{ '/quickstart' | relative_url }}">Quick Start</a></li>
          <li><a href="{{ '/commands-core' | relative_url }}">Core Commands</a></li>
          <li><a href="{{ '/commands-wp' | relative_url }}">WP-CLI Commands</a></li>
          <li><a href="{{ '/commands-ai' | relative_url }}">AI Commands</a></li>
          <li><a href="{{ '/configuration' | relative_url }}">Configuration</a></li>
          <li><a href="{{ '/examples' | relative_url }}">Examples</a></li>
        </ul>
      </nav>
    </div>

    <div class="content">
      <h1>{{ page.title | default: site.title | default: site.github.repository_name }}</h1>
      
      {{ content }}

      <footer style="margin-top: 50px; padding-top: 20px; border-top: 1px solid #e1e4e8;">
        {% if site.github.is_project_page %}
        <p>This project is maintained by <a href="{{ site.github.owner_url }}">{{ site.github.owner_name }}</a></p>
        {% endif %}
        <p><small>Hosted on GitHub Pages</small></p>
      </footer>
    </div>
  </div>
</body>
</html>
